"use client";

import type {IAllReferralCodeRes, IApiAllTradesRes, IApiUserAssetsRes} from "@/interfaces/api.interface";
import { IUserWalletCryptos } from "@/interfaces/crypto.interface";
import { EReturnState, type IStandardisedReturn } from "@/interfaces/general.interface";
import type { IUserData, IUserWallet } from "@/interfaces/userdata.interface";
import ApiRequest from "@/services/apiRequest";
import type { Dispatch, SetStateAction } from "react";

//TODO Run disconnect task
export function doDisconnect() {
	if (typeof window !== "undefined") {
		window.localStorage.removeItem("sub");
		//Redirect to homepage
		window.location.href = "/";
		return true;
	}
	console.log(
		"Whut ? Why trying to remove an item from the localStorage when running in SSR ?",
	);
	return false;
}

export async function getWallet(): Promise<IStandardisedReturn<IApiUserAssetsRes>> {
	try {
		const ReqRes =
			await ApiRequest.authenticated.get.json<IStandardisedReturn<IApiUserAssetsRes>>(
				"user/my-assets",
			);
		console.log(ReqRes.data);

		if (ReqRes.status !== 200) {
			return {
				state: EReturnState.clientError,
			};
		}
		return {
			state: EReturnState.done,
			resolved: ReqRes.data,
		};
	} catch (err) {
		return {
			state: EReturnState.serverError,
		};
	}
}

export async function getUserTrades() {
	try {
		const ReqRes =
			await ApiRequest.authenticated.get.json<IStandardisedReturn<IApiAllTradesRes>>(
				"user/my-trades",
			);
		console.log(ReqRes.data);

		if (ReqRes.status !== 200) {
			return {
				state: EReturnState.clientError,
			};
		}
		return {
			state: EReturnState.done,
			resolved: ReqRes.data,
		};
	} catch (err) {
		return {
			state: EReturnState.serverError,
		};
	}
}

export async function getAlltrades() {
	try {
		const ReqRes =
			await ApiRequest.authenticated.get.json<IStandardisedReturn<IApiAllTradesRes>>(
				"trade/all",
			);
		console.log(ReqRes.data);

		if (ReqRes.status !== 200) {
			return {
				state: EReturnState.clientError,
			};
		}
		return {
			state: EReturnState.done,
			resolved: ReqRes.data,
		};
	} catch (err) {
		return {
			state: EReturnState.serverError,
		};
	}
}

export async function createTrade(data: any) {
	const ReqRes =
    await ApiRequest.authenticated.post.json<IStandardisedReturn<IApiAllTradesRes>>(
      "trade/create",
			{

			}
    );
  console.log(ReqRes.data);

  if (ReqRes.status !== 200) {
    return {
      state: EReturnState.clientError,
    };
  }
  return {
    state: EReturnState.done,
    resolved: ReqRes.data,
  };
}

export async function getAllTrade() {
	const ReqRes =
    await ApiRequest.authenticated.get.json<IStandardisedReturn<IApiAllTradesRes>>(
      "trade/all",
    );
  console.log(ReqRes.data);

  if (ReqRes.status !== 200) {
    return {
      state: EReturnState.clientError,
    };
  }
  return {
    state: EReturnState.done,
    resolved: ReqRes.data,
  };
}

export async function getUserTrade() {
	const ReqRes =
      await ApiRequest.authenticated.get.json<IStandardisedReturn<IApiAllTradesRes>>(
        "user/my-trades",
      );
    console.log(ReqRes.data);

    if (ReqRes.status !== 200) {
      return {
        state: EReturnState.clientError,
      };
    }
    return {
      state: EReturnState.done,
      resolved: ReqRes.data,
    };
}

export async function getAllReferralCode() {
	const ReqRes =
      await ApiRequest.authenticated.get.json<IStandardisedReturn<IAllReferralCodeRes>>(
        "promoCode/all",
      );
    console.log(ReqRes.data);

    if (ReqRes.status !== 200) {
      return {
        state: EReturnState.clientError,
      };
    }
    return {
      state: EReturnState.done,
      resolved: ReqRes.data,
    };
}

export async function createReferralCode(data: any) {
	const ReqRes =
      await ApiRequest.authenticated.post.json<IStandardisedReturn<IAllReferralCodeRes>>(
        "promoCode/create",
        data
      );
    console.log(ReqRes.data);

    if (ReqRes.status !== 200) {
      return {
        state: EReturnState.clientError,
      };
    }
    return {
      state: EReturnState.done,
      resolved: ReqRes.data,
    };
}

export async function getAllCryptos() {}

export async function getCryptoHistory(cryptoId: string) {}

export async function sellCrypto() {}

export async function buyCrypto() {}